==> latte-dock-0.9.12.tar.xz: latte-dock-0.9.12/shell/metadata.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Name=Latte Shell
Name[ca]=Intèrpret d'ordres del Latte
Name[ca@valencia]=Intèrpret d'ordres del Latte
Name[cs]=Shell Latte
Name[da]=Latte-skal
Name[de]=Latte-Shell
Name[el]=Κέλυφος Latte
Name[en_GB]=Latte Shell
Name[es]=Consola de Latte
Name[et]=Latte shell
Name[eu]=Latte Shell-a
Name[fi]=Latte-käyttöliittymä
Name[fr]=Interpréteur de commandes pour Latte
Name[gl]=Intérprete de ordes de Latte
Name[id]=Shell Latte
Name[it]=shell Latte
Name[ko]=Latte 셸
Name[nl]=Latte-shell
Name[nn]=Latte-skal
Name[pl]=Powłoka Latte
Name[pt]=Consola do Latte
Name[pt_BR]=Latte Shell
Name[ru]=Оболочка Latte
Name[sk]=Shell Latte
Name[sl]=Shell Latte
Name[sv]=Latte skal
Name[uk]=Оболонка Латте
Name[x-test]=xxLatte Shellxx
Name[zh_CN]=Latte Shell
Name[zh_TW]=Latte Shell
Comment=Shell provided for the Latte Dock
Comment[ca]=Intèrpret d'ordres proporcionat per l'acoblador Latte
Comment[ca@valencia]=Intèrpret d'ordres proporcionat per l'acoblador Latte
Comment[da]=Skal til Latte-dokken
Comment[de]=Shell für Latte-Dock
Comment[el]=Κέλυφος που παρέχεται από την εφαρμογή Latte
Comment[en_GB]=Shell provided for the Latte Dock
Comment[es]=Shell proporcionada para Latte Dock
Comment[et]=Latte doki shell
Comment[eu]=Shell-a Latte Dockentzat
Comment[fi]=Latte-telakalle tarjottu käyttöliittymä
Comment[fr]=Interpréteur de commandes fourni pour le panneau Latte
Comment[gl]=Intérprete de ordes fornecido para a doca Latte.
Comment[id]=Shell disediakan untuk Dock Latte
Comment[it]=Shell fornita per Latte Dock
Comment[ko]=Latte 독용 셸
Comment[nl]=Shell geleverd voor de Latte Dock
Comment[nn]=Skal frå Latte-dokk
Comment[pl]=Powłoka dla doku Latte
Comment[pt]=Consola oferecida para a área acoplável do Latte
Comment[pt_BR]=Shell fornecido pelo Latte Dock
Comment[ru]=Оболочка для Latte Dock
Comment[sk]=Shell poskytnutý pre dok Latte
Comment[sl]=Shell za dok Latte
Comment[sv]=Skal tillhandahållet för Latte dockningsfönster
Comment[uk]=Оболонка панелі Латте
Comment[x-test]=xxShell provided for the Latte Dockxx
Comment[zh_CN]=用于 Latte 停靠栏的 Shell
Comment[zh_TW]=由 Latte Dock 提供的 Shell

Keywords=shell
Keywords[ca]=intèrpret d'ordres
Keywords[ca@valencia]=intèrpret d'ordres
Keywords[cs]=shell
Keywords[da]=skal
Keywords[de]=Shell
Keywords[el]=κέλυφος
Keywords[en_GB]=shell
Keywords[es]=consola
Keywords[et]=shell
Keywords[eu]=shell
Keywords[fi]=käyttöliittymä
Keywords[fr]=interpréteur
Keywords[gl]=intérprete de ordes
Keywords[id]=shell
Keywords[it]=shell
Keywords[ko]=셸
Keywords[nl]=shell
Keywords[nn]=skal
Keywords[pl]=powłoka
Keywords[pt]=consola
Keywords[pt_BR]=shell
Keywords[ru]=оболочка
Keywords[sk]=shell
Keywords[sl]=shell
Keywords[sv]=skal
Keywords[uk]=оболонка
Keywords[x-test]=xxshellxx
Keywords[zh_CN]=shell
Keywords[zh_TW]=shell
Type=Service

X-KDE-ServiceTypes=Plasma/Shell
X-KDE-ParentApp=latte-dock
X-KDE-PluginInfo-Author=@AUTHOR@
X-KDE-PluginInfo-Email=@EMAIL@
X-KDE-PluginInfo-License=GPLv3+
X-KDE-PluginInfo-Name=org.kde.latte.shell
X-KDE-PluginInfo-Version=@VERSION@
X-KDE-PluginInfo-Website=@WEBSITE@

==> latte-dock-0.10.8.tar.xz: latte-dock-0.10.8/shell/metadata.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Name=Latte Shell
Name[az]=Latte Üzlüyü
Name[ca]=Intèrpret d'ordres del Latte
Name[ca@valencia]=Intèrpret d'ordres del Latte
Name[cs]=Shell Latte
Name[da]=Latte-skal
Name[de]=Latte-Shell
Name[el]=Κέλυφος Latte
Name[en_GB]=Latte Shell
Name[es]=Consola de Latte
Name[et]=Latte shell
Name[eu]=Latte Shell-a
Name[fi]=Latte-käyttöliittymä
Name[fr]=Interpréteur de commandes pour Latte
Name[gl]=Intérprete de ordes de Latte
Name[id]=Shell Latte
Name[it]=shell Latte
Name[ko]=Latte 셸
Name[lt]=Latte apvalkalas
Name[nl]=Latte-shell
Name[nn]=Latte-skal
Name[pl]=Powłoka Latte
Name[pt]=Consola do Latte
Name[pt_BR]=Latte Shell
Name[ru]=Оболочка Latte
Name[sk]=Latte Shell
Name[sl]=Shell Latte
Name[sv]=Latte skal
Name[uk]=Оболонка Латте
Name[x-test]=xxLatte Shellxx
Name[zh_CN]=Latte Shell
Name[zh_TW]=Latte Shell
Comment=Shell provided for the Latte Dock
Comment[az]=Latte Dok paneli üçün nəzərdə tutulan üzlük
Comment[ca]=Intèrpret d'ordres proporcionat per l'acoblador Latte
Comment[ca@valencia]=Intèrpret d'ordres proporcionat per l'acoblador Latte
Comment[da]=Skal til Latte-dokken
Comment[de]=Shell für Latte-Dock
Comment[el]=Κέλυφος που παρέχεται από την εφαρμογή Latte
Comment[en_GB]=Shell provided for the Latte Dock
Comment[es]=Shell proporcionada para Latte Dock
Comment[et]=Latte doki shell
Comment[eu]=Shell-a Latte Dockentzat
Comment[fi]=Latte-telakalle tarjottu käyttöliittymä
Comment[fr]=Interpréteur de commandes fourni pour le panneau Latte
Comment[gl]=Intérprete de ordes fornecido para a doca Latte.
Comment[id]=Shell disediakan untuk Dock Latte
Comment[it]=Shell fornita per Latte Dock
Comment[ko]=Latte 독용 셸
Comment[lt]=Latte dokui teikiamas apvalkalas
Comment[nl]=Shell geleverd voor de Latte Dock
Comment[nn]=Skal frå Latte-dokk
Comment[pl]=Powłoka dla doku Latte
Comment[pt]=Consola oferecida para a área acoplável do Latte
Comment[pt_BR]=Shell fornecido pelo Latte Dock
Comment[ru]=Оболочка для Latte Dock
Comment[sl]=Shell za dok Latte
Comment[sv]=Skal tillhandahållet för Latte dockningsfönster
Comment[uk]=Оболонка панелі Латте
Comment[x-test]=xxShell provided for the Latte Dockxx
Comment[zh_CN]=用于 Latte 停靠栏的 Shell
Comment[zh_TW]=由 Latte Dock 提供的 Shell

Keywords=shell
Keywords[az]=üzlük
Keywords[ca]=intèrpret d'ordres
Keywords[ca@valencia]=intèrpret d'ordres
Keywords[cs]=shell
Keywords[da]=skal
Keywords[de]=Shell
Keywords[el]=κέλυφος
Keywords[en_GB]=shell
Keywords[es]=consola
Keywords[et]=shell
Keywords[eu]=shell
Keywords[fi]=käyttöliittymä
Keywords[fr]=interpréteur
Keywords[gl]=intérprete de ordes
Keywords[ia]=shell
Keywords[id]=shell
Keywords[it]=shell
Keywords[ko]=셸
Keywords[lt]=apvalkalas
Keywords[nl]=shell
Keywords[nn]=skal
Keywords[pl]=powłoka
Keywords[pt]=consola
Keywords[pt_BR]=shell
Keywords[ru]=оболочка
Keywords[sk]=shell
Keywords[sl]=shell
Keywords[sv]=skal
Keywords[uk]=оболонка
Keywords[x-test]=xxshellxx
Keywords[zh_CN]=shell
Keywords[zh_TW]=shell
Type=Service

X-KDE-ServiceTypes=Plasma/Shell
X-KDE-ParentApp=latte-dock
X-KDE-PluginInfo-Author=@AUTHOR@
X-KDE-PluginInfo-Email=@EMAIL@
X-KDE-PluginInfo-License=GPLv3+
X-KDE-PluginInfo-Name=org.kde.latte.shell
X-KDE-PluginInfo-Version=@VERSION@
X-KDE-PluginInfo-Website=@WEBSITE@
